# Release Notes

## 2025-01-28 - version 0.0.28
## What's Changed
* Removed hyperlint by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/179
* mlflow update by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/180

[**Full Changelog**](https://github.com/mlinfra-io/mlinfra/compare/0.0.27...0.0.28)

---

## 2024-12-27 - version 0.0.27
* minor-fixes by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/178


[**Full Changelog**](https://github.com/mlinfra-io/mlinfra/compare/0.0.26...0.0.27)

---

## 2024-12-27 - version 0.0.26

* update-readme by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/176
* updated python version and dependencies by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/177


[**Full Changelog**](https://github.com/mlinfra-io/mlinfra/compare/0.0.25...0.0.26)

---

## 2024-12-26 - version 0.0.25

* 173-feature-setup-uv-lock by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/174
* Changed terraform s3 backend from dynamodb to s3 lockfile by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/175


[**Full Changelog**](https://github.com/mlinfra-io/mlinfra/compare/0.0.24...0.0.25)

---

## 2024-11-04 - version 0.0.24

* fix: updated-cli-for-utils by @aliabbasjaffri in [#157](https://github.com/mlinfra-io/mlinfra/pull/157)


[**Full Changelog**](https://github.com/mlinfra-io/mlinfra/compare/0.0.23...0.0.24)

---

## 2024-11-03 - version 0.0.23

* fix: update-release-notes-gh-action by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/156


[**Full Changelog**](https://github.com/mlinfra-io/mlinfra/compare/0.0.22...0.0.23)

---

## 2024-11-03 - version 0.0.22

* fix: update-release-notes-formatting by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/154
* dependabot: bump mkdocs-material from 9.5.27 to 9.5.43 by @dependabot in https://github.com/mlinfra-io/mlinfra/pull/148
* dependabot: bump mkdocs from 1.6.0 to 1.6.1 by @dependabot in https://github.com/mlinfra-io/mlinfra/pull/136
* dependabot: bump virtualenv from 20.26.2 to 20.27.1 by @dependabot in https://github.com/mlinfra-io/mlinfra/pull/147
* dependabot: bump babel from 2.15.0 to 2.16.0 by @dependabot in https://github.com/mlinfra-io/mlinfra/pull/138
* dependabot: bump pytz from 2024.1 to 2024.2 by @dependabot in https://github.com/mlinfra-io/mlinfra/pull/135
* chore: bumped-dev-dependencies by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/155


[**Full Changelog**](https://github.com/mlinfra-io/mlinfra/compare/0.0.21...0.0.22)

---

## 2024-11-03 - version 0.0.21

* fix: broken-release-for pypa1.11 by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/153


[**Full Changelog**](https://github.com/mlinfra-io/mlinfra/compare/0.0.20...0.0.21)

---

## 2024-11-02 - version 0.0.20

* fix: Set attestation as false in pypi release by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/152
* [Snyk] Security upgrade zipp from 3.15.0 to 3.19.1 by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/151


[**Full Changelog**](https://github.com/mlinfra-io/mlinfra/compare/0.0.19...0.0.20)

---

##  2024-11-02 - version 0.0.19

* 99 replace cli to typer by @aliabbasjaffri in https://github.com/mlinfra-io/mlinfra/pull/149
* Fixing docs publishing


[**Full Changelog**](https://github.com/mlinfra-io/mlinfra/compare/0.0.18...0.0.19)
